==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGroupingStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebGroupByExpandStateDescriptionMetadata } from "./WebGroupByExpandStateDescriptionMetadata";
import { WebGroupingStateDescription } from "./WebGroupingStateDescription";
/**
 * @hidden
 */
export let WebGroupingStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupingStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupingStateDescriptionMetadata.a == null) {
                WebGroupingStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupingStateDescriptionMetadata.c(WebGroupingStateDescriptionMetadata.a);
            }
            if (a.k(WebGroupingStateDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGroupingStateDescriptionMetadata.a);
            WebGroupingExpressionDescriptionMetadata.d(a);
            WebGroupByExpandStateDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupingState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("__isTSPlainInterface", "Boolean");
            a.item("Expressions", "Array:WebGroupingExpressionDescription:GroupingExpression");
            a.item("Expansion", "Array:WebGroupByExpandStateDescription:GroupByExpandState");
            a.item("DefaultExpanded", "Boolean");
        }
        static d(a) {
            WebGroupingStateDescriptionMetadata.b(a);
            a.ad("WebGroupingState", () => new WebGroupingStateDescription());
            a.ac("WebGroupingState", WebGroupingStateDescriptionMetadata.a);
        }
    }
    WebGroupingStateDescriptionMetadata.$t = markType(WebGroupingStateDescriptionMetadata, 'WebGroupingStateDescriptionMetadata');
    WebGroupingStateDescriptionMetadata.a = null;
    return WebGroupingStateDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGroupingStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebGroupByExpandStateDescriptionMetadata } from "./WebGroupByExpandStateDescriptionMetadata";
import { WebGroupingStateDescription } from "./WebGroupingStateDescription";
/**
 * @hidden
 */
export let WebGroupingStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupingStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupingStateDescriptionMetadata.a == null) {
                WebGroupingStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupingStateDescriptionMetadata.c(WebGroupingStateDescriptionMetadata.a);
            }
            if (a.k(WebGroupingStateDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGroupingStateDescriptionMetadata.a);
            WebGroupingExpressionDescriptionMetadata.d(a);
            WebGroupByExpandStateDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupingState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("__isTSPlainInterface", "Boolean");
            a.item("Expressions", "Array:WebGroupingExpressionDescription:GroupingExpression");
            a.item("Expansion", "Array:WebGroupByExpandStateDescription:GroupByExpandState");
            a.item("DefaultExpanded", "Boolean");
        }
        static d(a) {
            WebGroupingStateDescriptionMetadata.b(a);
            a.ae("WebGroupingState", () => new WebGroupingStateDescription());
            a.ad("WebGroupingState", WebGroupingStateDescriptionMetadata.a);
        }
    }
    WebGroupingStateDescriptionMetadata.$t = markType(WebGroupingStateDescriptionMetadata, 'WebGroupingStateDescriptionMetadata');
    WebGroupingStateDescriptionMetadata.a = null;
    return WebGroupingStateDescriptionMetadata;
})();
